%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Ring-type sensor program to calibrate sensor for annular flow pattern
% and get calibration curve for annular flows
% -----------------------------------------------------------------------
% The code has to be in the same folder as the stated QF problem
% QuickField problem has to be open
% Modify geometrcial parameters of QuickField problem
% DO NOT CHANGE ANY LABELS OR ADD/DELETE ANY LABELS
% -----------------------------------------------------------------------
% Input the following parameters:
%   distance as constant: Distance between electrodes in mm
%   length_electrodes as constant: Length of both electrodes in mm
%   r_i as constant: inner radius of pipe in mm
%   y_vec as vector: move line between liquid and vapour phase in steps (mm)
%   epsilon_r.vapour as struct: relative permittivity of vapour phase
%   epsilon_r.liquid as struct: relative permittivity of liquid phase
%   Names_Blocks as cell-struct: label of blocks, DO NOT CHANGE THEIR NAMES
%   spacing as constant: spacing of each vertex for grid
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
close all
clearvars
clc
%% Parameters
distance = 2;
length_electrodes = 10;
r_i = 12;
y_vec = sqrt(linspace(0,(r_i-0.3)^2,10));
epsilon_r.vapour = 1;
epsilon_r.liquid = 80;
Names_Blocks.Liquid={'Liquid_l' , 'Liquid_m' , 'Liquid_r'};
Names_Blocks.Vapour={'Vapour_l' , 'Vapour_m' , 'Vapour_r'};
spacing = 0.1;
%% Set geometry of the model and spacing
fnc_set_model(epsilon_r , Names_Blocks , distance, length_electrodes, r_i)
fnc_set_spacing(spacing)

%% Calculate calibration curve
num_for_tot=length(y_vec);
% Initialise matrix and vector for results
Res_mat_SL=zeros(num_for_tot+2,3);
for num_for=1:num_for_tot
    % Function to calculate:
    % Void fraction | Capacitance 
    y_i=y_vec(num_for);
    Res_mat_SL(num_for+1,:) = fnc_alpha_capacitance(y_i);
end
% Calculate alpha = 1 and alpha = 0
fnc_set_model_vapour(epsilon_r , Names_Blocks)
Res_mat_SL(end,:) = fnc_alpha_capacitance_vapour;
fnc_set_model_liquid(epsilon_r , Names_Blocks)
Res_mat_SL(1,:) = fnc_alpha_capacitance_liquid;

%% Plot results capacitance over void fraction
% With dimensions
figure(1)
plot(Res_mat_SL(:,3)*10^12,Res_mat_SL(:,1),'-ok',...
        'LineWidth',1.5,...
        'MarkerSize',6,...
        'MarkerEdgeColor','r');hold on;   
%xlim([0,1])
%ylim([0,1])
axes1 = gca;
set(axes1,'FontSize',12,'LineWidth',1.5,...
    'MinorGridAlpha',0,...
    'TickLabelInterpreter','latex','TickLength',[0.01 0]);
    %'XTick',[0:0.2:1],'YTick',[0:0.2:1]);
xlabel({'$Capacitance$ $(pF)$'},'FontSize',12,'FontWeight','bold','FontName','Times',...
    'Interpreter','latex');
ylabel('$Void$ $fraction$ $(-)$','FontSize',12,'FontWeight','bold','FontName','Times',...
    'Interpreter','latex');

% Dimensionless
figure(2)
plot((Res_mat_SL(:,3)-Res_mat_SL(end,3))/...
    (Res_mat_SL(1,3)-Res_mat_SL(end,3)),Res_mat_SL(:,1),'-ok',...
        'LineWidth',1.5,...
        'MarkerSize',6,...
        'MarkerEdgeColor','r');hold on;
plot([0,1],[1,0],'--k',...
        'LineWidth',1);hold on;    
xlim([0,1])
ylim([0,1])
axes1 = gca;
set(axes1,'FontSize',12,'LineWidth',1.5,...
    'MinorGridAlpha',0,...
    'TickLabelInterpreter','latex','TickLength',[0.01 0],...
    'XTick',[0:0.2:1],'YTick',[0:0.2:1]);
xlabel({'$Capacitance$ $(pF)$'},'FontSize',12,'FontWeight','bold','FontName','Times',...
    'Interpreter','latex');
ylabel('$Void$ $fraction$ $(-)$','FontSize',12,'FontWeight','bold','FontName','Times',...
    'Interpreter','latex');



%Get values for calibration curve
%Values for curve fitting toolbox
y_data = Res_mat_SL(:,1);
x_data_1 = (Res_mat_SL(:,3)-Res_mat_SL(end,3))/...
    (Res_mat_SL(1,3)-Res_mat_SL(end,3));



        