function [Res_Output] = fnc_alpha_capacitance_vapour

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Function to calculate void fraction, stored energy and
% capacity for given distance betwenn the electrodes
%
% Output parameters:
%   Res_Output as matrix: 
%                   Void fraction 
%                   W_vapour stored energy of pure vapour 
%                   C_vapour capacitance of pure vapour
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Vapour phase

% 1. Step: Create link between Matlab and Quickfield
%get link to QuickField
qf = actxserver ('QuickField.Application'); 
%get link to the problem
prb = qf.Problems.Item(1);      
%load model
prb.LoadModel;                  
%get link to the model
mdl = prb.Model;    
 
% 3. Step Calculate the results
%solve problem
prb.SolveProblem();             
%load results
prb.AnalyzeResults;
%get link to the result
res = prb.Result;               
%open the field window
theFieldWindow = res.GetFieldWindow(1);

% 4. Get Stored Energy of Capacitor:
%get link to the contour
theContour = theFieldWindow.Contour; 
%add block to contour 
theContour.AddBlock1 ('Liquid_l');     
theContour.AddBlock1 ('Liquid_m');
theContour.AddBlock1 ('Liquid_r');    
theContour.AddBlock1 ('Vapour_l');    
theContour.AddBlock1 ('Vapour_m');    
theContour.AddBlock1 ('Vapour_r');
%calculate the integral of desired value
theStoredEnergy_Vapour = res.GetIntegral('qfInt_ElectrostaticEnergy', theContour).Value; %Result.GetIntegral (QfIntegrals, Contour).Quantity
%Delete the contour for new contour     
theContour.DeleteBlock1 ('Liquid_l');     
theContour.DeleteBlock1 ('Liquid_m');
theContour.DeleteBlock1 ('Liquid_r');    
theContour.DeleteBlock1 ('Vapour_l');    
theContour.DeleteBlock1 ('Vapour_m');    
theContour.DeleteBlock1 ('Vapour_r'); 

% 5. Get void fraction:
alpha=1;
%% Results 

% 7 Create output vector:
% Get voltage of each electrode (only positive values, negative sign is
% neglected) and calculate potential
U_l=prb.Labels ('qfEdge').Item ('E_l').Content.Dirichlet;
U_r=prb.Labels ('qfEdge').Item ('E_r').Content.Dirichlet;
V_lr=abs(U_l-U_r);
% Calculate capacitance using stored energy: C = 2*W/(V)^2
theCapacitance_Vapour=2*theStoredEnergy_Vapour/(V_lr)^2;
% Void fraction | W | C
Res_Output=[alpha , theStoredEnergy_Vapour , theCapacitance_Vapour];


end


