function fnc_set_model_vapour(epsilon_r , Names_Blocks)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Function to change model data: relative permitivitties of liquid and
% vapour phase
%
% Input parameters: 
%   epsilon_r.vapour as struct: relative permittivity of vapour phase
%   epsilon_r.liquid as struct: relative permittivity of liquid phase
%   Names_Blocks as cell-struct: label of blocks, DO NOT CHANGE THEIR NAMES
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% 1. Step: Create link between Matlab and Quickfield
%get link to QuickField
qf = actxserver ('QuickField.Application'); 
%get link to the problem
prb = qf.Problems.Item(1);      
%load model
prb.LoadModel;                  
%get link to the model
mdl = prb.Model;    

% 2. Set electric permittivity of Liquid blocks and vapour blocks
%Liquid blocks
for n_for=1:length(Names_Blocks.Liquid)
    % get desired label
    blocklabels=prb.Labels ('qfBlock');
    blocklab=blocklabels.Item (Names_Blocks.Liquid{n_for});
    % get content of block n_for
    blocklabCnt=blocklab.Content;
    % modify content 
    blocklabCnt.set ('Kxx',false,epsilon_r.liquid); 
    blocklabCnt.set ('Kyy',false,epsilon_r.liquid); 
    % Change modified content of the desired label
    blocklab.Content=blocklabCnt;
    blocklab.DataDoc.Save
end
%Vapour blocks
for n_for=1:length(Names_Blocks.Liquid)
    % get desired label
    blocklabels=prb.Labels ('qfBlock');
    blocklab=blocklabels.Item (Names_Blocks.Vapour{n_for});
    % get content of block n_for
    blocklabCnt=blocklab.Content;
    % modify content 
    blocklabCnt.set ('Kxx',false,epsilon_r.liquid); 
    blocklabCnt.set ('Kyy',false,epsilon_r.liquid); 
    % Change modified content of the desired label
    blocklab.Content=blocklabCnt;
    blocklab.DataDoc.Save
end

%build mesh in the model
mdl.Shapes.BuildMesh();
%save model file
mdl.Save; 


end